# Contributing

When contributing to this repository, please first discuss the change you wish to make via issue,
email, or any other method with the participants of this repository before making a change.

Please note we have a code of conduct [here](https://github.com/maekind/pylembic/blob/main/.github/CODE_OF_CONDUCT.md), please follow it in all your interactions with the project.

## Issue process

1. Create an issue from one of the existing templates (bug or feature).
2. Create a new branch and link it to the issue.
   - Naming rule: the name of the new branch must be [the type of the issue]/[issue number]_short_PR_description. **Remember that the type of the issue only can be *bugfix* or *feature*.**

## Pull Request Process

1. Create the pull request and select at least one participant as reviewer.
2. You may merge the Pull Request once you have the sign-off of the reviewer, or if you
   do not have permission to do that, you may request the participants to merge it for you.

This document could evolve in the future.
